/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.jvm;

import org.gradle.jvm.ClassDirectoryBinarySpec;
import org.gradle.jvm.internal.AbstractJvmBinaryRenderer;
import org.gradle.model.internal.manage.schema.ModelSchemaStore;

import javax.inject.Inject;

public class ClassDirectoryBinaryRenderer extends AbstractJvmBinaryRenderer<ClassDirectoryBinarySpec> {
    @Inject
    public ClassDirectoryBinaryRenderer(ModelSchemaStore schemaStore) {
        super(schemaStore);
    }

    @Override
    public Class<ClassDirectoryBinarySpec> getTargetType() {
        return ClassDirectoryBinarySpec.class;
    }
}
